@@ -1,5 +1,6 @@
 from .all import AllValidator
 from .any import AnyValidator
+from .e164 import E164Validator
 from .tuple import TupleValidator
 from .bool import BoolValidator
 from .dict import DictValidator
@@ -33,5 +34,6 @@ __all__ = [
     TypeValidator,
     Validator,
     ValidationError,
-    EmailValidator
+    EmailValidator,
+    E164Validator
 ]
\ No newline at end of file
