@@ -1,9 +1,9 @@
 from .str import StrValidator
 from .base import Validator
-from email.utils import parseaddr
+from validate_email import validate_email
 
 class EmailValidator(Validator):
     def validate(self, ctx, value):
         StrValidator().validate(ctx, value)
-        if len(parseaddr(value)[1]) == 0:
+        if not validate_email(value):
             ctx.error("value is not an email", value = value)
\ No newline at end of file
